"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.searchProgressModelFormatter = void 0;
/*
 * Copyright 2020-2023 SynTest contributors
 *
 * This file is part of SynTest Framework - SynTest Framework.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const search_1 = require("@syntest/search");
function searchProgressModelFormatter(searchAlgorithm, subject, budgetManager) {
    const iterations = budgetManager
        .getBudgetObject(search_1.BudgetType.ITERATION)
        .getUsedBudget();
    const evaluations = budgetManager
        .getBudgetObject(search_1.BudgetType.EVALUATION)
        .getUsedBudget();
    let searchTime = budgetManager
        .getBudgetObject(search_1.BudgetType.SEARCH_TIME)
        .getUsedBudget();
    let totalTime = budgetManager
        .getBudgetObject(search_1.BudgetType.TOTAL_TIME)
        .getUsedBudget();
    searchTime = Math.round(searchTime * 1000) / 1000;
    totalTime = Math.round(totalTime * 1000) / 1000;
    const covered = [
        ...searchAlgorithm.getObjectiveManager().getCoveredObjectives(),
    ];
    const uncovered = [
        ...searchAlgorithm.getObjectiveManager().getUncoveredObjectives(),
    ];
    // record covered
    const coveredPaths = 0;
    const coveredBranches = covered.filter((objectiveFunction) => objectiveFunction instanceof search_1.BranchObjectiveFunction).length;
    const coveredFunctions = covered.filter((objectiveFunction) => objectiveFunction instanceof search_1.FunctionObjectiveFunction).length;
    const coveredExceptions = covered.filter((objectiveFunction) => objectiveFunction instanceof search_1.ExceptionObjectiveFunction).length;
    const coveredLines = 0;
    const coveredImplicitBranches = covered.filter((objectiveFunction) => objectiveFunction instanceof search_1.ImplicitBranchObjectiveFunction).length;
    const coveredObjectives = covered.length;
    // record totals
    const totalPaths = 0;
    const totalBranches = coveredBranches +
        uncovered.filter((objectiveFunction) => objectiveFunction instanceof search_1.BranchObjectiveFunction).length;
    const totalFunctions = coveredFunctions +
        uncovered.filter((objectiveFunction) => objectiveFunction instanceof search_1.FunctionObjectiveFunction).length;
    const totalExceptions = coveredExceptions +
        uncovered.filter((objectiveFunction) => objectiveFunction instanceof search_1.ExceptionObjectiveFunction).length;
    const totalLines = 0;
    const totalImplicitBranches = coveredImplicitBranches +
        uncovered.filter((objectiveFunction) => objectiveFunction instanceof search_1.ImplicitBranchObjectiveFunction).length;
    const totalObjectives = coveredObjectives + uncovered.length;
    return {
        iteration: iterations,
        evaluation: evaluations,
        searchTime: searchTime,
        totalTime: totalTime,
        coveredPaths,
        coveredBranches,
        coveredExceptions,
        coveredFunctions,
        coveredLines,
        coveredImplicitBranches,
        coveredObjectives,
        totalPaths,
        totalBranches,
        totalExceptions,
        totalFunctions,
        totalLines,
        totalImplicitBranches,
        totalObjectives,
    };
}
exports.searchProgressModelFormatter = searchProgressModelFormatter;
//# sourceMappingURL=SearchProgressModel.js.map